
# Type: prefix_prefix


the nsname (sans ':' for a given prefix)

URI: [meta:prefix_prefix](https://w3id.org/biolink/biolinkml/meta/prefix_prefix)


## Domain and Range

[Prefix](Prefix.md) ->  <sub>REQ</sub> [Ncname](types/Ncname.md)

## Parents


## Children


## Used by

 * [Prefix](Prefix.md)
